@@ -44,8 +44,8 @@ os.environ['PYTHONHASHSEED'] = str(seed)
 from DLStudio import *
 
 dls = DLStudio(
-                  dataroot = "/home/kak/ImageDatasets/PurdueShapes5/",
-#                  dataroot = "./data/PurdueShapes5/",
+#                  dataroot = "/home/kak/ImageDatasets/PurdueShapes5/",
+                  dataroot = "./data/PurdueShapes5/",
                   image_size = [32,32],
                   path_saved_model = "./saved_model",
                   momentum = 0.9,
@@ -79,14 +79,11 @@ model = detector.LOADnet2(skip_connections=True, depth=8)
 number_of_learnable_params = sum(p.numel() for p in model.parameters() if p.requires_grad)
 print("\n\nThe number of learnable parameters in the model: %d" % number_of_learnable_params)
 
-num_layers = len(list(model.parameters()))
-print("\nThe number of layers in the model: %d\n\n" % num_layers)
-
-
 detector.run_code_for_training_with_CrossEntropy_and_MSE_Losses(model, show_images=True)
 
-import pymsgbox
-response = pymsgbox.confirm("Finished training.  Start testing on unseen data?")
-if response == "OK": 
-    detector.run_code_for_testing_detection_and_localization(model)
+#import pymsgbox
+#response = pymsgbox.confirm("Finished training.  Start testing on unseen data?")
+#if response == "OK": 
+
+detector.run_code_for_testing_detection_and_localization(model)
 
