@@ -1,15 +1,15 @@
 # -*- coding: utf-8 -*-
 
-__version__   = '2.4.8'
+__version__   = '2.5.0'
 __author__    = "Avinash Kak (kak@purdue.edu)"
-__date__      = '2024-April-27'                   
-__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.4.8.html'
+__date__      = '2024-September-7'                   
+__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.5.0.html'
 __copyright__ = "(C) 2024 Avinash Kak. Python Software Foundation."
 
 
 __doc__  =  '''
 
-You are looking at the GenerativeDiffusion co-class file in the DLStudio platform.
+You are looking at the GenerativeDiffusion module file in the DLStudio platform.
 For the overall documentation on DLStudio, visit:
 
            https://engineering.purdue.edu/kak/distDLS/
@@ -32,7 +32,7 @@ Dhariwal that you can download from:
 
          https://arxiv.org/pdf/2102.09672.pdf
 
-That GitHub code library consist of roughly 3900 lines of Python distributed over
+That GitHub code library consists of roughly 3900 lines of Python distributed over
 10 files in three different directories.  The code you'll see here contains around
 750 lines of that code and that too after several changes to simplify the
 organization of the code and to also simplify the call syntax for many of the
