@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 
-__version__   = '2.4.8'
+__version__   = '2.5.0'
 __author__    = "Avinash Kak (kak@purdue.edu)"
-__date__      = '2024-April-27'                   
-__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.4.8.html'
+__date__      = '2024-September-7'                   
+__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.5.0.html'
 __copyright__ = "(C) 2024 Avinash Kak. Python Software Foundation."
 
 
