@@ -1,16 +1,16 @@
 # -*- coding: utf-8 -*-
 
-__version__   = '2.4.8'
+__version__   = '2.5.0'
 __author__    = "Avinash Kak (kak@purdue.edu)"
-__date__      = '2024-April-27'                   
-__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.4.8.html'
+__date__      = '2024-September-7'                   
+__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.5.0.html'
 __copyright__ = "(C) 2024 Avinash Kak. Python Software Foundation."
 
 
 __doc__ = '''
 
 
-  You are looking at the Seq2SeqLearning co-class file in the DLStudio platform.
+  You are looking at the Seq2SeqLearning module file in the DLStudio platform.
   For the overall documentation on DLStudio, visit:
 
            https://engineering.purdue.edu/kak/distDLS/
