@@ -10,6 +10,8 @@ if sys.version_info[0] == 3:
     from DLStudio.DLStudio import __copyright__
     from Transformers.Transformers import TransformerFG
     from Transformers.Transformers import TransformerPreLN
+    from Transformers.Transformers import visTransformer
+    from Transformers.Transformers import Autoencoder
 else:
     sys.exit("The transformer code in DLStudio has only been tested for Python 3")
 
